import java.io.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.filechooser.*;

class TextEditor extends JFrame implements ActionListener {
	private static JFrame frame;
	private JTextArea textArea;
	private JFileChooser chooser = new JFileChooser(".");

	public static void main(String[] args) {
		// 自分自身のインスタンス化
		frame = new TextEditor();
		// フレームのセットアップ
		frame.setDefaultCloseOperation(frame.EXIT_ON_CLOSE);	// 終了時処理
		frame.pack();	// サイズの自動セット
		frame.setVisible(true);	// 可視化（リアライズ）
	}

	// コンストラクタ
	TextEditor(){
		// スーパークラスのコンストラクタ呼び出し
		super("ファイル入出力");

		// 開くボタンの作成
		JButton open = new JButton("開く");
		open.setActionCommand("Open");	// イベント発生時に文字列"Open"を発生
		open.addActionListener(this);

		// 保存ボタンの作成
		JButton save = new JButton("保存");
		save.setActionCommand("Save");	// イベント発生時に文字列"Close"を発生
		save.addActionListener(this);

		// テキスト・エリアの作成
		textArea = new JTextArea();
    	textArea.setWrapStyleWord(true);
 		textArea.setLineWrap(true);

		// スクロールパネルにテキスト・エリアを追加
		JScrollPane scroll = new JScrollPane(textArea);
		scroll.setVerticalScrollBarPolicy(JScrollPane.VERTICAL_SCROLLBAR_ALWAYS);
		scroll.setPreferredSize(new Dimension(250, 250));

		// パネルに部品を追加
		JPanel panel = new JPanel();
		panel.add(open);
		panel.add(save);

		// コンテント・ペインの取得
		Container cnt = getContentPane();
		// コンテント・ペインに部品を追加
		cnt.add(panel, BorderLayout.NORTH);
		cnt.add(scroll, BorderLayout.CENTER);
	}

	// イベント処理
	public void actionPerformed(ActionEvent ae){
		if(ae.getActionCommand() == "Open"){	// Openボタンが押されたときの処理
			int returnVal = chooser.showOpenDialog(this);	// [Open File]用JFileChooserの可視化
			                                                // 戻り値ではJFileChooserが閉じられたのが、
			                                                // ＯＫボタンによるのかキャンセルボタンによるのかを識別
			try {
				if (returnVal == JFileChooser.APPROVE_OPTION) {	// ＯＫボタンでJFileChooserが閉じられた後の処理
					File file = chooser.getSelectedFile();	// 選択されたファイルの抽象パスを取得
					FileReader fr
						= new FileReader(file);	// 文字ファイル読み込み簡易ストリーム
					textArea.read(fr, null);	// テキスト・エリアに文字列セット
					frame.setTitle(file.getAbsolutePath());	// フレームのタイトル変更
					fr.close();	// 読み込みバッファのクローズ
				}
			} catch(Exception ex){}
		} else if (ae.getActionCommand() == "Save") {	// Saveボタンが押されたときの処理
			int returnVal = chooser.showSaveDialog(this);
			try{
				if (returnVal == JFileChooser.APPROVE_OPTION) {
					FileWriter fw
						= new FileWriter(chooser.getSelectedFile());
					fw.write(textArea.getText());
					fw.close();
				}
			}
			catch(Exception ex){
				ex.printStackTrace();
			}
		}
	}
}
